/*
  AntiRight
  (c) 2003-2004 Jeffrey Bedard
  jefbed@e-list.net
 
  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "library.h"

Widget
antiright_menubar(Widget parent_widget)
{
  Widget menubar_widget;

  /* The form widget is the standard AntiRight layout widget.  If it
     is not used, these attachments are simply ignored.  */
  antiright_form_positions(0, ANTIRIGHT_NONE, 0, 100);
  menubar_widget=XmCreateMenuBar(parent_widget, 
				 "menubar", 
				 antiright_arguments, 
				 antiright_number_arguments);
  XtManageChild(menubar_widget);

  return(menubar_widget);
}

/* This is a function that greatly shortens the time needed to create
   a pulldown menu.  */
Widget 
antiright_menu(Widget parent_widget, 
	       char* name)
{
  Widget menu;
  Widget cascade;

  antiright_set(XmNtearOffModel, XmTEAR_OFF_ENABLED);
  menu= XmCreatePulldownMenu(parent_widget, 
			     name, 
			     antiright_arguments, 
			     antiright_number_arguments);
  
  ARCLARG;
  antiright_set(XmNsubMenuId, (XtArgVal)menu);
  cascade=XmCreateCascadeButton(parent_widget, 
				name, 
				antiright_arguments, 
				antiright_number_arguments);
  XtManageChild(cascade);
  ARCLARG;
  return(menu);
}

/* Free the returned value after using.  */
char*
antiright_help_command(char* file_string)
{
  char* command_string;
  
  asprintf(&command_string,
	   "ARO %s/share/doc/antiright/%s &",
	   PREFIX,
	   file_string);
  return(command_string);
}

Widget
antiright_setup_help_cascade(Widget menubar_widget,
			     Widget menu_widget)
{
  Widget cascade_widget;

  ARCLARG;
  antiright_set(XmNsubMenuId, (XtArgVal)menu_widget);
  cascade_widget=XmCreateCascadeButton(menubar_widget,
				       "Help", 
				       antiright_arguments, 
				       antiright_number_arguments);
  XtManageChild(cascade_widget);

  XtVaSetValues(menubar_widget, 
		XmNmenuHelpWidget, 
		cascade_widget,
		NULL);
}

Widget
antiright_create_help_menu(Widget menubar_widget)
{
  Widget menu_widget;
  
  ARCLARG;  
  antiright_set(XmNtearOffModel, XmTEAR_OFF_ENABLED);
  menu_widget=XmCreatePulldownMenu(menubar_widget, 
				   "Help",
				   antiright_arguments, 
				   antiright_number_arguments);
  antiright_setup_help_cascade(menubar_widget, menu_widget);  

  return(menu_widget);
}

void
antiright_help_manual_cb(Widget parent_widget,
			 XtPointer client_data,
			 XtPointer call_data)
{
  char* command_string;
  
  asprintf(&command_string, "ACE -A Manual_Page %s &", client_data);
  antiright_system(command_string);
  free(command_string);
}

void
antiright_license_cb(Widget parent_widget,
		     XtPointer client_data,
		     XtPointer call_data)
{
  char* command_string;
  asprintf(&command_string, "ARO %s/share/doc/antiright/COPYING", PREFIX);
  antiright_system(command_string);
  free(command_string);
}

Widget
antiright_help_menu(Widget menubar_widget)
{
  Widget menu_widget;
  Widget submenu_widget;

  menu_widget=antiright_create_help_menu(menubar_widget);
  submenu_widget=antiright_menu(menu_widget, "Manual");
  antiright_button(submenu_widget, 
		   "ACE", 
		   antiright_help_manual_cb, 
		   "ACE");
  antiright_button(submenu_widget, 
		   "arcd", 
		   antiright_help_manual_cb, 
		   "arcd");
  antiright_button(submenu_widget, 
		   "system.antiright", 
		   antiright_help_manual_cb, 
		   "system.antiright");
  antiright_separator(menu_widget);
  antiright_button(menu_widget,
                   "About AntiRight", 
		   antiright_help_cb,
                   "AntiRight is a lightweight desktop environment.");
  antiright_button(menu_widget, 
		   "Copyright", 
		   antiright_help_cb, 
		   "Copyright 2002-2004, Jeffrey E. Bedard");
  antiright_button(menu_widget, 
		   "License", 
		   antiright_license_cb, 
		   "License");
  antiright_button(menu_widget, 
		   "No Warranty", 
		   antiright_help_cb, 
		   "There is NO warranty.  USE AT YOUR OWN RISK!");
  antiright_button(menu_widget, 
		   "On Version", 
		   antiright_help_cb, 
		   PACKAGE_STRING);
  return(menu_widget);
}

Widget
antiright_edit_menu(Widget menubar_widget,
		    Widget text_widget)
{
  Widget edit_menu_widget;

  edit_menu_widget=antiright_menu(menubar_widget, 
				  "Edit");
  
  (Widget)antiright_button(edit_menu_widget,
			   "Cut",
			   antiright_cut_cb,
			   text_widget);
  
  (Widget)antiright_button(edit_menu_widget,
			   "Copy",
			   antiright_copy_cb,
			   text_widget);
  
  (Widget)antiright_button(edit_menu_widget,
			   "Paste",
			   antiright_paste_cb,
			   text_widget);

  return(edit_menu_widget);
}

void
antiright_setup_file_menu(struct antiright_menubar_structure* menubar)
{
  menubar->file_widget=antiright_menu(menubar->menubar_widget, "File");
  antiright_button(menubar->file_widget, "Close", antiright_exit_cb, NULL);
}

void
antiright_setup_view_menu(struct antiright_menubar_structure* menubar)
{
  menubar->view_widget=antiright_menu(menubar->menubar_widget, "View");
  antiright_button(menubar->view_widget, "ACE Panel",
		   antiright_system_cb, "ACE");
  antiright_button(menubar->view_widget, "Administration Panel",
		   antiright_system_cb, "ACE -A Administration_Panel");
  antiright_button(menubar->view_widget, "File System Panel", 
		   antiright_system_cb, "ACE -A File_System_Panel");
  antiright_button(menubar->view_widget, "Network Panel", 
		   antiright_system_cb, "ACE -A Network_Panel");
  antiright_button(menubar->view_widget, "Themes Panel", 
		   antiright_system_cb, "ACE -A Theme_Panel");
}

void
antiright_setup_help_menu(struct antiright_menubar_structure* menubar)
{
  menubar->help_widget=antiright_help_menu(menubar->menubar_widget);
}


struct antiright_menubar_structure
antiright_define_menubar(struct antiright_menubar_structure menubar, 
			 Widget text_widget) /*  This is used by the
						 edit menu for the
						 source and
						 destination for the
						 text that is to be
						 copied, cut, and
						 pasted.  Set to NULL
						 if not used.  */
{
  antiright_setup_file_menu(&menubar);
  if(text_widget != NULL)
      antiright_edit_menu(menubar.menubar_widget, text_widget);
  antiright_setup_view_menu(&menubar);
  antiright_setup_help_menu(&menubar);

  return(menubar);
}

struct antiright_menubar_structure
antiright_defined_menubar(Widget parent_widget, /* This is the parent
						   of the menubar,
						   which is usually
						   your main window
						   widget.  */
			  Widget text_widget) /*  This is used by the
						  edit menu for the
						  source and
						  destination for the
						  text that is to be
						  copied, cut, and
						  pasted.  */
{
  struct antiright_menubar_structure menubar;
  
  menubar.menubar_widget=antiright_menubar(parent_widget);
  menubar=antiright_define_menubar(menubar, text_widget);
  
  return(menubar);
}
